@@ -15,8 +15,9 @@ fractional components (e.g. 40729 is 2011-07-05, 37145.354166666664 is 2001-09-1
 We need a whitelist so we know to only do this date conversions for date fields and
 not all columns with numeric values.
 
-With the modern XML-based, XLSX format however, qsv will automatically process a cell as a date,
-even if its not its not in the --dates-whitelist, if the cell's format has been explicitly set to date.
+With the modern XML-based, XLSX format however (Excel 2007 and later), qsv will automatically process
+a cell as a date, even if its not its not in the --dates-whitelist, if the cell's format has been
+explicitly set to date.
 
 For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_excel.rs.
 
@@ -25,7 +26,7 @@ Usage:
     qsv excel --help
 
 Excel options:
-    -s, --sheet <name/index>   Name or zero-based index of sheet to export.
+    -s, --sheet <name/index>   Name (case-insensitive) or zero-based index of sheet to export.
                                Negative indices start from the end (-1 = last sheet). 
                                If the sheet cannot be found, qsv will read the first sheet.
                                [default: 0]
@@ -265,10 +266,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             num_sheets,
             sheet: vec![],
         };
-        #[allow(clippy::needless_range_loop)]
-        for i in 0..num_sheets {
-            let sheet_name = sheet_vec[i].clone();
-
+        for (i, sheet_name) in sheet_vec.iter().enumerate() {
             let range = if let Some(result) = workbook.worksheet_range_at(i) {
                 match result {
                     Ok(result) => result,
@@ -329,7 +327,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 };
             let sheetmetadata_struct = SheetMetadata {
                 index: i,
-                name: sheet_name,
+                name: sheet_name.to_string(),
                 headers: header_vec,
                 num_columns,
                 num_rows,
@@ -344,31 +342,37 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
         match metadata_mode {
             MetadataMode::Csv => {
-                record.push_field("index");
-                record.push_field("sheet_name");
-                record.push_field("headers");
-                record.push_field("num_columns");
-                record.push_field("num_rows");
-                record.push_field("safe_headers");
-                record.push_field("safe_headers_count");
-                record.push_field("unsafe_headers");
-                record.push_field("unsafe_headers_count");
-                record.push_field("duplicate_headers_count");
+                let mut metadata_fields = Vec::with_capacity(10);
+                metadata_fields.extend_from_slice(&[
+                    "index",
+                    "sheet_name",
+                    "headers",
+                    "num_columns",
+                    "num_rows",
+                    "safe_headers",
+                    "safe_headers_count",
+                    "unsafe_headers",
+                    "unsafe_headers_count",
+                    "duplicate_headers_count",
+                ]);
+                record = csv::StringRecord::from(metadata_fields);
 
                 wtr.write_record(&record)?;
 
                 for sheetmetadata in excelmetadata_struct.sheet {
-                    record.clear();
-                    record.push_field(&sheetmetadata.index.to_string());
-                    record.push_field(&sheetmetadata.name);
-                    record.push_field(&format!("{:?}", sheetmetadata.headers));
-                    record.push_field(&sheetmetadata.num_columns.to_string());
-                    record.push_field(&sheetmetadata.num_rows.to_string());
-                    record.push_field(&format!("{:?}", sheetmetadata.safe_headers));
-                    record.push_field(&sheetmetadata.safe_headers_count.to_string());
-                    record.push_field(&format!("{:?}", sheetmetadata.unsafe_headers));
-                    record.push_field(&sheetmetadata.unsafe_headers_count.to_string());
-                    record.push_field(&sheetmetadata.duplicate_headers_count.to_string());
+                    let metadata_values = vec![
+                        sheetmetadata.index.to_string(),
+                        sheetmetadata.name,
+                        format!("{:?}", sheetmetadata.headers),
+                        sheetmetadata.num_columns.to_string(),
+                        sheetmetadata.num_rows.to_string(),
+                        format!("{:?}", sheetmetadata.safe_headers),
+                        sheetmetadata.safe_headers_count.to_string(),
+                        format!("{:?}", sheetmetadata.unsafe_headers),
+                        sheetmetadata.unsafe_headers_count.to_string(),
+                        sheetmetadata.duplicate_headers_count.to_string(),
+                    ];
+                    record = csv::StringRecord::from(metadata_values);
 
                     wtr.write_record(&record)?;
                 }
@@ -395,10 +399,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
 
     // convert sheet_names to lowercase so we can do a case-insensitive compare
-    let mut lower_sheet_names: Vec<String> = Vec::with_capacity(num_sheets);
-    for s in sheet_names {
-        lower_sheet_names.push(s.to_lowercase());
-    }
+    let lower_sheet_names: Vec<String> = sheet_names.iter().map(|s| s.to_lowercase()).collect();
 
     // if --sheet name was passed, see if its a valid sheet name.
     let mut sheet = if lower_sheet_names.contains(&args.flag_sheet.to_lowercase()) {
@@ -407,8 +408,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         // otherwise, if --sheet is a number, its a zero-based index, fetch it
         if let Ok(sheet_index) = args.flag_sheet.parse::<i32>() {
             if sheet_index >= 0 {
-                if sheet_index as usize <= sheet_names.len() {
-                    sheet_names[sheet_index as usize].to_string()
+                if let Some(sheet_name) = sheet_names.get(sheet_index as usize) {
+                    sheet_name.to_string()
                 } else {
                     return fail_clierror!(
                         "sheet index {sheet_index} is greater than number of sheets {}",
@@ -429,6 +430,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             }
         } else {
             // failing all else, get the first sheet
+            // safety: its safe to use index access here as sheet_names is guaranteed to have at
+            // least one element as we check if its not empty in  the beginning
             let first_sheet = sheet_names[0].to_string();
             info!(
                 r#"Invalid sheet "{}". Using the first sheet "{}" instead."#,
@@ -436,11 +439,14 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             );
             first_sheet
         }
-    };
-    let lower_sheet = sheet.to_lowercase();
-    let sheet_index = if let Some(idx) = lower_sheet_names.iter().position(|s| *s == lower_sheet) {
+    }
+    .to_lowercase();
+
+    let sheet_index = if let Some(idx) = lower_sheet_names.iter().position(|s| *s == sheet) {
         // set to actual name of the sheet, not the one passed using the --sheet option,
         // as we process the option case insensitively
+        // safety: it's safe to use index access here because lower_sheet_names is a lowercase copy
+        // of sheet_names
         sheet = sheet_names[idx].clone();
         idx
     } else {
@@ -495,7 +501,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut trimmed_record = csv::StringRecord::with_capacity(200, 20);
     let mut date_flag: Vec<bool> = Vec::with_capacity(20);
 
-    let mut cell_date_flag: bool;
+    let mut cell_date_flag: bool = false;
     let mut float_val = 0_f64;
     let mut float_flag: bool;
     let mut row_count = 0_usize;
@@ -550,7 +556,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 info!("date_flag: {date_flag:?}");
                 continue;
             }
-            cell_date_flag = false;
             float_flag = false;
             match *cell {
                 DataType::Empty => record.push_field(""),
@@ -567,19 +572,23 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 DataType::Float(ref f) => {
                     float_val = *f;
                     float_flag = true;
-                    cell_date_flag = date_flag[col_idx];
+                    cell_date_flag = *date_flag.get(col_idx).unwrap_or(&false);
                 }
                 DataType::Error(ref e) => record.push_field(&format!("{e:?}")),
                 DataType::Bool(ref b) => record.push_field(&b.to_string()),
             };
 
-            // dates are stored as floats in Excel
-            // that's why we need the --dates-whitelist, so we can convert the float to a date.
-            // However, with the XLSX format, we can get a cell's format as an attribute. So we can
-            // automatically process a cell as a date, even if its column is NOT in the whitelist
+            // Dates are stored as floats in Excel's older binary format (XLS - Excel 97-2003.)
+            // That's why we need the --dates-whitelist, so we can convert the float to a date.
+            // However, with the more recent XLSX format (Excel 2007 & later), we can get a cell's
+            // format as a cell attribute. So we can automatically process a cell as a date,
+            // even if its column is NOT in the whitelist
+            #[allow(clippy::cast_precision_loss)]
             if float_flag {
                 if cell_date_flag {
+                    // its a date, so convert it
                     work_date = if float_val.fract() > 0.0 {
+                        // if it has a fractional part, then its a datetime
                         if let Some(dt) = cell.as_datetime() {
                             if date_format.is_empty() {
                                 // no date format specified, so we'll just use the default
@@ -598,6 +607,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                             format!("ERROR: Cannot convert {float_val} to datetime")
                         }
                     } else if let Some(d) = cell.as_date() {
+                        // if it has no fractional part and calamine can return it as_date
+                        // then its a date
                         if date_format.is_empty() {
                             d.to_string()
                         } else {
@@ -611,10 +622,17 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         format!("ERROR: Cannot convert {float_val} to date")
                     };
                     record.push_field(&work_date);
-                } else if float_val.fract() > 0.0 {
+                // its not a date, so just push the ryu-formatted float value if its not an integer
+                // or the candidate integer is too big or too small to be an i64
+                } else if float_val.fract().abs() > 0.0
+                    || float_val > i64::MAX as f64
+                    || float_val < i64::MIN as f64
+                {
                     let mut buffer = ryu::Buffer::new();
                     record.push_field(buffer.format_finite(float_val));
                 } else {
+                    // its an i64 integer. We can't use ryu to format it, because it will
+                    // be formatted as a float (have a ".0"). So we use itoa.
                     let mut buffer = itoa::Buffer::new();
                     record.push_field(buffer.format(float_val as i64));
                 }
